import {
    Button, Modal, ModalService, Select, Tabs, TextInput, Text, LoadingService, Form, DialogService,
} from '@zeedhi/common';
import { Utilities } from '@/util/Utilities';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class ContractModelController {
    public tekgridContractModelVisible: boolean = true;

    public currentRow: any = {};

    public currentRowViewSignatariosPadroes: any = {};

    private basicModal!: Modal;

    private ModalViewSignatariosPadroes!: Modal;

    get formContractModelVisible() {
        return !this.tekgridContractModelVisible;
    }

    public changeFacilities({ component }: any) {
        const intlocal = Metadata.getInstance<Select>(`${component.name.split('_')[0]}_IDINTEGRALOCAISFM`);
        const intmed = Metadata.getInstance<Select>(`${component.name.split('_')[0]}_IDINTEGRAMEDICAOFM`);
        if (component.value === 'S') {
            intlocal.disabled = false;
            intmed.disabled = false;
        } else {
            intlocal.disabled = true;
            intmed.disabled = true;
            intlocal.value = null;
            intmed.value = null;
        }
    }

    public changeTecFood({ component }: any) {
        const tiposerv = Metadata.getInstance<Select>(`${component.name.split('_')[0]}_IDTIPOSERVINTTECFOOD`);

        if (component.value === 'S') {
            tiposerv.disabled = false;
        } else {
            tiposerv.disabled = true;
            tiposerv.value = null;
        }
    }
    
    public changeAssinatura({ component }: any) {
        const tipodoc = Metadata.getInstance<TextInput>(`${component.name.split('_')[0]}_NRTIPODOCCERTSIGN`);
        const enviarDoc = Metadata.getInstance<Select>(`${component.name.split('_')[0]}_IDENVIADOCOPERRESPCONCASS`);

        if (component.value === 'S') {
            tipodoc.disabled = false;
            enviarDoc.disabled = false;
        } else {
            tipodoc.disabled = true;
            enviarDoc.disabled = true;
            tipodoc.value = null;
            enviarDoc.value = null;
        }
    }

    public expandir({ component }: any) {
        const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
        form.isVisible = !form.isVisible;

        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    public backTekGridContractModel() {
        this.tekgridContractModelVisible = true;
    }

    get textFrameContractModel() {
        return this.currentRow.NMMODCONTRATO;
    }

    public openFrameContractModel({ row }: any) {
        this.tekgridContractModelVisible = false;
        this.currentRow = row;
        this.loadTabsContractModel();
    }

    public loadTabsContractModel() {
        const setOfTabs = Metadata.getInstance<Tabs>('tabsInformationContractModel');

        if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_contractModelTab') {
            this.contractModelTab();
        } else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_contractModelTabEscopoFaturamento') {
            this.contractModelTabEscopoFaturamento();
        } else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_contractModelTabModeloDocumento') {
            this.contractModelTabModeloDocumento();
        } else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_contractModelTabPerfisAcesso') {
            this.contractModelTabPerfisAcesso();
        } else if (setOfTabs.tabs[setOfTabs.activeTab].name === 'tab_contractModelTabSignatariosPadroes') {
            this.contractModelTabSignatariosPadroes();
        }
    }

    public contractModelTab() {
        Metadata.getInstance<TextInput>('contractModelTab-NMMODCONTRATO').value = this.currentRow.NMMODCONTRATO;
        Metadata.getInstance<TextInput>('contractModelTab-IDATIVO').value = this.currentRow.IDATIVO;
        Metadata.getInstance<TextInput>('contractModelTab-CDMODCONTRATO').value = this.currentRow.CDMODCONTRATO;
        Metadata.getInstance<TextInput>('contractModelTab-IDGERAPROPOSTA').value = this.currentRow.IDGERAPROPOSTA;
        Metadata.getInstance<TextInput>('contractModelTab-CDCENTCUST').value = this.currentRow.CDCENTCUST;
        Metadata.getInstance<TextInput>('contractModelTab-NRDIASVIGCONT').value = this.currentRow.NRDIASVIGCONT;
        Metadata.getInstance<TextInput>('contractModelTab-IDRENOVACAOAUTOMATICA').value = this.currentRow.IDRENOVACAOAUTOMATICA;
        Metadata.getInstance<TextInput>('contractModelTab-NRDIASPRORGCONT').value = this.currentRow.NRDIASPRORGCONT;
        Metadata.getInstance<TextInput>('contractModelTab-IDBLOQALTDTINICONTRENEG').value = this.currentRow.IDBLOQALTDTINICONTRENEG;
        Metadata.getInstance<TextInput>('contractModelTab-IDREAJUSTEAUTOMATICO').value = this.currentRow.IDREAJUSTEAUTOMATICO;
        Metadata.getInstance<TextInput>('contractModelTab-NRDIASREAJAUTOMATICO').value = this.currentRow.NRDIASREAJAUTOMATICO;
        Metadata.getInstance<TextInput>('formIntegracaoFacilities_IDINTEGRACAOFM').value = this.currentRow.IDINTEGRACAOFM;
        Metadata.getInstance<TextInput>('formIntegracaoHcm_IDINTEGRACAOHCM').value = this.currentRow.IDINTEGRACAOHCM;
        Metadata.getInstance<TextInput>('formIntegracaoFacilities_IDINTEGRALOCAISFM').value = this.currentRow.IDINTEGRALOCAISFM;
        Metadata.getInstance<TextInput>('formIntegracaoFacilities_IDINTEGRAMEDICAOFM').value = this.currentRow.IDINTEGRAMEDICAOFM;
        Metadata.getInstance<TextInput>('formContractModelDigital_IDASSELETRDIGITAL').value = this.currentRow.IDASSELETRDIGITAL;
        Metadata.getInstance<TextInput>('formContractModelDigital_NRTIPODOCCERTSIGN').value = this.currentRow.NRTIPODOCCERTSIGN;
        Metadata.getInstance<TextInput>('formContractModelDigital_IDENVIADOCOPERRESPCONCASS').value = this.currentRow.IDENVIADOCOPERRESPCONCASS;
        Metadata.getInstance<Select>('formIntegraTecFood_IDINTEGRACAOTECFOOD').value = this.currentRow.IDINTEGRACAOTECFOOD;
        Metadata.getInstance<Select>('formIntegraTecFood_IDTIPOSERVINTTECFOOD').value = this.currentRow.IDTIPOSERVINTTECFOOD;
    }

    public contractModelTabEscopoFaturamento() {
        try {
            const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-escopo-faturamento');
            grid.datasource.setFilter({
                NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            });
        } catch (e) {
            // console.error(e);
        }
    }

    public contractModelTabModeloDocumento() {
        try {
            const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-modelo-documento');
            grid.datasource.setFilter({
                NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            });
        } catch (e) {
            // console.error(e);
        }
    }

    public editContractModel() {
        const formDadosContractModelAddDadosModelo = Metadata.getInstance<Form>('contractModelTab-formRowDadosModelo');
        const formDadosContractModelAddIntegracao = Metadata.getInstance<Form>('formIntegracaoFacilities');
        const formContractModelDigital = Metadata.getInstance<Form>('formAssEletronica');
        const formTecFood = Metadata.getInstance<Form>('formIntegraTecFood');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-contract-model_grid');
        const params = {
            NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            NMMODCONTRATO: Metadata.getInstance<Select>('contractModelTab-NMMODCONTRATO').value,
            IDATIVO: Metadata.getInstance<Select>('contractModelTab-IDATIVO').value,
            CDMODCONTRATO: Metadata.getInstance<Select>('contractModelTab-CDMODCONTRATO').value,
            IDGERAPROPOSTA: Metadata.getInstance<Select>('contractModelTab-IDGERAPROPOSTA').value,
            CDCENTCUST: Metadata.getInstance<Select>('contractModelTab-CDCENTCUST').value,
            NRDIASVIGCONT: Metadata.getInstance<Select>('contractModelTab-NRDIASVIGCONT').value,
            IDRENOVACAOAUTOMATICA: Metadata.getInstance<Select>('contractModelTab-IDRENOVACAOAUTOMATICA').value,
            NRDIASPRORGCONT: Metadata.getInstance<Select>('contractModelTab-NRDIASPRORGCONT').value,
            IDBLOQALTDTINICONTRENEG: Metadata.getInstance<Select>('contractModelTab-IDBLOQALTDTINICONTRENEG').value,
            IDREAJUSTEAUTOMATICO: Metadata.getInstance<Select>('contractModelTab-IDREAJUSTEAUTOMATICO').value,
            NRDIASREAJAUTOMATICO: Metadata.getInstance<Select>('contractModelTab-NRDIASREAJAUTOMATICO').value,
            IDINTEGRACAOFM: Metadata.getInstance<Select>('formIntegracaoFacilities_IDINTEGRACAOFM').value,
            IDINTEGRALOCAISFM: Metadata.getInstance<Select>('formIntegracaoFacilities_IDINTEGRALOCAISFM').value,
            IDINTEGRAMEDICAOFM: Metadata.getInstance<Select>('formIntegracaoFacilities_IDINTEGRAMEDICAOFM').value,
            IDASSELETRDIGITAL: Metadata.getInstance<Select>('formContractModelDigital_IDASSELETRDIGITAL').value,
            NRTIPODOCCERTSIGN: Metadata.getInstance<Select>('formContractModelDigital_NRTIPODOCCERTSIGN').value,
            IDENVIADOCOPERRESPCONCASS: Metadata.getInstance<Select>('formContractModelDigital_IDENVIADOCOPERRESPCONCASS').value,
            IDINTEGRACAOTECFOOD: Metadata.getInstance<Select>('formIntegraTecFood_IDINTEGRACAOTECFOOD').value,
            IDTIPOSERVINTTECFOOD: Metadata.getInstance<Select>('formIntegraTecFood_IDTIPOSERVINTTECFOOD').value,
            IDINTEGRACAOHCM: Metadata.getInstance<Select>('formIntegracaoHcm_IDINTEGRACAOHCM').value,
        };

        if (Utilities.validateForm(formDadosContractModelAddDadosModelo) && Utilities.validateForm(formDadosContractModelAddIntegracao) && Utilities.validateForm(formTecFood) && Utilities.validateForm(formContractModelDigital)) {
            LoadingService.show();
            Http.post('/editContractModel', params).then(() => {
                grid.datasource.get();
                this.backTekGridContractModel();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public editContractModelTabModeloDocumento({ component }: any) {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-modelo-documento');

        if (Utilities.validateGrid(grid)) {
            LoadingService.show();

            Http.post('/editContractModelTabModeloDocumento', {
                EDITEDROWS: component.getEditedRows(),
            }).then(() => {
                component.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public editContractModelTabSignatariosPadroes() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-signatarios-padroes');

        if (Utilities.validateGrid(grid)) {
            LoadingService.show();
            const EDITEDROWS = {
                NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
                NRSIGNATPADRCONT: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRSIGNATPADRCONT').value,
                IDTPSIGNATARIO: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-IDTPSIGNATARIO').value,
                NRPARCNEGOCIO: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRPARCNEGOCIO').value,
                IDTIPOASSINATURA: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-IDTIPOASSINATURA').value,
                IDTESTEMUNHA: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-IDTESTEMUNHA').value,
                NRORDENACAO: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRORDENACAO').value,
                DSEMAILNOTSIGNENV: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-DSEMAILNOTSIGNENV').value,
                DSEMAILNOTIFOUTROS: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-DSEMAILNOTIFOUTROS').value,
                CDOPERADOR: Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-CDOPERADOR').value,
            };
            Http.post('/editContractModelTabSignatariosPadroes', EDITEDROWS).then(() => {
                this.closeViewSignatariosPadroes();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public contractModelTabPerfisAcesso() {
        try {
            const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-perfis-acesso');
            grid.datasource.setFilter({
                NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            });
        } catch (e) {
            // console.error(e);
        }
    }

    public contractModelTabSignatariosPadroes() {
        try {
            const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-signatarios-padroes');
            grid.datasource.setFilter({
                NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            });
        } catch (e) {
            // console.error(e);
        }
    }

    public openFilterContractModel({ component }: any) {
        const filterButton = Metadata.getInstance<Button>(`${component.name}_filterButton`);
        filterButton.click({} as Event, {} as HTMLElement);
    }

    public closeModalAddContractModel() {
        this.basicModal.hide();
        this.basicModal?.destroy();
    }

    public async openModalAddContractModel() {
        await this.showModalAddContractModel();
        Metadata.getInstance<Text>('titleText').text = 'Novo Modelo de Contrato';
    }

    public async openModalContractModelAddTabEscopoFaturamento() {
        await this.showModalContractModelAddTabEscopoFaturamento();
        Metadata.getInstance<Text>('titleText').text = 'Escopo de Faturamento';
    }

    public async openModalContractModelAddTabModeloDocumento() {
        await this.showModalContractModelAddTabModeloDocumento();
        Metadata.getInstance<Text>('titleText').text = 'Modelo de Documento';
    }

    public async openModalContractModelAddTabPerfisAcesso() {
        await this.showModalContractModelAddTabPerfisAcesso();
        Metadata.getInstance<Text>('titleText').text = 'Perfis de Acesso';
    }

    public async openModalContractModelAddTabSignatariosPadroes() {
        await this.showModalContractModelAddTabSignatariosPadroes();
        Metadata.getInstance<Text>('titleText').text = 'Signatários Padrões';
    }

    public async showModalAddContractModel() {
        this.basicModal = await ModalService.createFromJson('contractModel/modal/contractModelAdd', true);
        this.basicModal.show();
    }

    public async showModalContractModelAddTabEscopoFaturamento() {
        this.basicModal = await ModalService.createFromJson('contractModel/modal/contractModelAddTabEscopoFaturamento', true);
        this.basicModal.show();
    }

    public async showModalContractModelAddTabModeloDocumento() {
        this.basicModal = await ModalService.createFromJson('contractModel/modal/contractModelAddTabModeloDocumento', true);
        this.basicModal.show();
    }

    public async showModalContractModelAddTabPerfisAcesso() {
        this.basicModal = await ModalService.createFromJson('contractModel/modal/contractModelAddTabPerfisAcesso', true);
        this.basicModal.show();
    }

    public async showModalContractModelAddTabSignatariosPadroes() {
        this.basicModal = await ModalService.createFromJson('contractModel/modal/contractModelAddTabSignatariosPadroes', true);
        this.basicModal.show();
    }

    public saveModalAddContractModel() {
        const formDadosContractModelAddDadosModelo = Metadata.getInstance<Form>('formDadosContractModelAddDadosModelo');
        const formDadosContractModelFacilities = Metadata.getInstance<Form>('formDadosContractModelFacilities');
        const formDadosContractModelDigital = Metadata.getInstance<Form>('formDadosContractModelDigital');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-contract-model_grid');
        const params = {
            NMMODCONTRATO: Metadata.getInstance<Select>('formDadosContractModelAddDadosModelo-NMMODCONTRATO').value,
            IDATIVO: Metadata.getInstance<Select>('formDadosContractModelAddDadosModelo-IDATIVO').value,
            CDMODCONTRATO: Metadata.getInstance<Select>('formDadosContractModel-CDMODCONTRATO').value,
            IDGERAPROPOSTA: Metadata.getInstance<Select>('formDadosContractModel-IDGERAPROPOSTA').value,
            CDCENTCUST: Metadata.getInstance<Select>('formDadosContractModel-CDCENTCUST').value,
            NRDIASVIGCONT: Metadata.getInstance<Select>('formDadosContractModel-NRDIASVIGCONT').value,
            IDRENOVACAOAUTOMATICA: Metadata.getInstance<Select>('formDadosContractModel-IDRENOVACAOAUTOMATICA').value,
            NRDIASPRORGCONT: Metadata.getInstance<Select>('formDadosContractModel-NRDIASPRORGCONT').value,
            IDBLOQALTDTINICONTRENEG: Metadata.getInstance<Select>('formDadosContractModel-IDBLOQALTDTINICONTRENEG').value,
            IDREAJUSTEAUTOMATICO: Metadata.getInstance<Select>('formDadosContractModel-IDREAJUSTEAUTOMATICO').value,
            NRDIASREAJAUTOMATICO: Metadata.getInstance<Select>('formDadosContractModel-NRDIASREAJAUTOMATICO').value,
            IDINTEGRACAOFM: Metadata.getInstance<Select>('formDadosContractModelFacilities_IDINTEGRACAOFM').value,
            IDINTEGRALOCAISFM: Metadata.getInstance<Select>('formDadosContractModelFacilities_IDINTEGRALOCAISFM').value,
            IDINTEGRAMEDICAOFM: Metadata.getInstance<Select>('formDadosContractModelFacilities_IDINTEGRAMEDICAOFM').value,
            IDASSELETRDIGITAL: Metadata.getInstance<Select>('formDadosContractModelDigital_IDASSELETRDIGITAL').value,
            NRTIPODOCCERTSIGN: Metadata.getInstance<Select>('formDadosContractModelDigital_NRTIPODOCCERTSIGN').value,
            IDENVIADOCOPERRESPCONCASS: Metadata.getInstance<Select>('formDadosContractModelDigital_IDENVIADOCOPERRESPCONCASS').value,
            IDINTEGRACAOTECFOOD: Metadata.getInstance<Select>('formIntegracaoTecFood_IDINTEGRACAOTECFOOD').value,
            IDTIPOSERVINTTECFOOD: Metadata.getInstance<Select>('formIntegracaoTecFood_IDTIPOSERVINTTECFOOD').value,
        };
        if (Utilities.validateForm(formDadosContractModelAddDadosModelo) && Utilities.validateForm(formDadosContractModelFacilities) && Utilities.validateForm(formDadosContractModelDigital)) {
            LoadingService.show();
            Http.post('/saveModalAddContractModel', params).then(() => {
                this.closeModalAddContractModel();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDeleteMessage({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'ContractModelController.deleteContractModel');
    }

    public deleteContractModel() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-contract-model_grid');
        LoadingService.show();
        Http.post('/deleteContractModel', {
            NRS: grid.selectedRows.map((element: any) => element.NRSEQMODCONTRA),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public saveModalAddContractModelTabEscopoFaturamento() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-escopo-faturamento');
        const params = {
            NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            NRTIPOORCAMENTO: Metadata.getInstance<Select>('getEscopoDeFaturamento-NRTIPOORCAMENTO').value,
        };

        LoadingService.show();
        Http.post('/saveModalAddContractModelTabEscopoFaturamento', params).then(() => {
            this.closeModalAddContractModel();
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public saveModalAddContractModelTabModeloDocumento() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-modelo-documento');
        const params = {
            NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            NRSEQMODDOCFCT: Metadata.getInstance<Select>('formDadosContractModel-NRSEQMODDOCFCT').value,
            IDSITUACAOCONTRATO: Metadata.getInstance<Select>('formDadosContractModel-IDSITUACAOCONTRATO').value,
            IDPERMITEDOCX: Metadata.getInstance<Select>('formDadosContractModel-IDPERMITEDOCX').value,
        };

        LoadingService.show();
        Http.post('/saveModalAddContractModelTabModeloDocumento', params).then(() => {
            this.closeModalAddContractModel();
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public saveModalAddContractModelTabPerfisAcesso() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-perfis-acesso');
        const params = {
            NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
            NRPERFILACESSO: Metadata.getInstance<Select>('formDadosContractModel-NRPERFILACESSO').value,
        };

        LoadingService.show();
        Http.post('/saveModalAddContractModelTabPerfisAcesso', params).then(() => {
            this.closeModalAddContractModel();
            grid.datasource.get();
            Utilities.showSuccessMessage();
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public saveModalAddContractModelTabSignatariosPadroes() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-signatarios-padroes');
        const form = Metadata.getInstance<Form>('formDadosContractModelAddTabSignatariosPadroes');
        if (Utilities.validateForm(form)) {
            const params = {
                NRSEQMODCONTRA: this.currentRow.NRSEQMODCONTRA,
                IDTPSIGNATARIO: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-IDTPSIGNATARIO').value,
                NRPARCNEGOCIO: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-NRPARCNEGOCIO').value,
                IDTIPOASSINATURA: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-IDTIPOASSINATURA').value,
                IDTESTEMUNHA: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-IDTESTEMUNHA').value,
                NRORDENACAO: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-NRORDENACAO').value,
                DSEMAILNOTSIGNENV: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-DSEMAILNOTSIGNENV').value,
                CDOPERADOR: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-CDOPERADOR').value,
                DSEMAILNOTIFOUTROS: Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-DSEMAILNOTIFOUTROS').value,
            };

            LoadingService.show();
            Http.post('/saveModalAddContractModelTabSignatariosPadroes', params).then(() => {
                this.closeModalAddContractModel();
                grid.datasource.get();
                Utilities.showSuccessMessage();
            }).catch((error: any) => {
                Utilities.showErrorMessage(error);
            }).finally(() => {
                LoadingService.hide();
            });
        }
    }

    public showConfirmDeleteMessageTabModeloDocumento({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'ContractModelController.deleteContractModelTabModeloDocumento');
    }

    public deleteContractModelTabModeloDocumento() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-modelo-documento');
        LoadingService.show();
        Http.post('/deleteContractModelTabModeloDocumento', {
            NRS: grid.selectedRows.map((element: any) => element.NRSEQMODELOCCONTR),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showConfirmDeleteMessageTabPerfisAcesso({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'ContractModelController.deleteContractModelTabPerfisAcesso');
    }

    public deleteContractModelTabPerfisAcesso() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-perfis-acesso');
        LoadingService.show();
        Http.post('/deleteContractModelTabPerfisAcesso', {
            NRS: grid.selectedRows.map((element: any) => element.NRPERFILACESSO),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showConfirmDeleteMessageTabSignatariosPadroes({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'ContractModelController.deleteContractModelTabSignatariosPadroes');
    }

    public deleteContractModelTabSignatariosPadroes() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-signatarios-padroes');
        LoadingService.show();
        Http.post('/deleteContractModelTabSignatariosPadroes', {
            NRSIGNATPADRCONT: grid.selectedRows.map((element: any) => element.NRSIGNATPADRCONT),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public showConfirmDeleteMessageTabEscopoFaturamento({ event }: any) {
        Utilities.showConfirmDeleteMessage(event, 'ContractModelController.deleteContractModelTabEscopoFaturamento');
    }

    public deleteContractModelTabEscopoFaturamento() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-tab-escopo-faturamento');
        LoadingService.show();
        Http.post('/deleteContractModelTabEscopoFaturamento', {
            NRS: grid.selectedRows.map((element: any) => element.NRESCOPOMORCONT),
        }).then(() => {
            grid.selectedRows = [];
            grid.reload();
            Utilities.showSuccessMessage();
        }).catch((error) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
            DialogService.hide();
        });
    }

    public changeTipoSignatario() {
        const tipoSignatario = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-IDTPSIGNATARIO').value;
        const SIGNATARIO = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-NRPARCNEGOCIO');
        const TIPOASSINATURA = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-IDTIPOASSINATURA');
        const TESTEMUNHA = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-IDTESTEMUNHA');
        const CPF = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-CPF');

        if (tipoSignatario === 'SE') {
            SIGNATARIO.readonly = false;
            SIGNATARIO.addValidation('required', {});
            TIPOASSINATURA.readonly = false;
            TESTEMUNHA.readonly = false;
        } else {
            SIGNATARIO.readonly = true;
            SIGNATARIO.removeValidation('required');
            TIPOASSINATURA.readonly = true;
            TESTEMUNHA.readonly = true;

            SIGNATARIO.value = '';
            CPF.value = '';
        }
    }

    public preencheCpfSignatario() {
        const SIGNATARIO = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-NRPARCNEGOCIO').value;
        const CPF = Metadata.getInstance<Select>('formDadosContractModelAddTabSignatariosPadroes-CPF');
        CPF.value = '';
        LoadingService.show();
        Http.post('/getCpfSignatario', { signatario: SIGNATARIO }).then((response) => {
            CPF.value = response.data[0].NRINSCRICAOPARC;
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public preencheCpfViewSignatario() {
        const SIGNATARIO = Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRPARCNEGOCIO').value;
        const CPF = Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-CPF');
        CPF.value = '';
        LoadingService.show();
        Http.post('/getCpfSignatario', { signatario: SIGNATARIO }).then((response) => {
            CPF.value = response.data[0].NRINSCRICAOPARC;
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public async createViewSignatariosPadroes() {
        this.ModalViewSignatariosPadroes = await ModalService.createFromJson('/contractModel/modal/contractModelViewSignatariosPadroes', true);
        this.ModalViewSignatariosPadroes.hide();
    }

    public openViewSignatariosPadroes({ row }: any) {
        this.currentRowViewSignatariosPadroes = row;
        if (!Array.isArray(this.currentRowViewSignatariosPadroes.CDOPERADOR)) {
            this.currentRowViewSignatariosPadroes.CDOPERADOR = this.currentRowViewSignatariosPadroes.CDOPERADOR.split(',');
        }
        if (!Array.isArray(this.currentRowViewSignatariosPadroes.DSEMAILNOTSIGNENV)) {
            this.currentRowViewSignatariosPadroes.DSEMAILNOTSIGNENV = this.currentRowViewSignatariosPadroes.DSEMAILNOTSIGNENV.split('_');
        }
        this.ModalViewSignatariosPadroes.show();
    }

    public closeViewSignatariosPadroes() {
        this.ModalViewSignatariosPadroes.hide();
    }

    public preencheViewSignatariosPadroes() {
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRSIGNATPADRCONT').value = this.currentRowViewSignatariosPadroes.NRSIGNATPADRCONT;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-IDTPSIGNATARIO').value = this.currentRowViewSignatariosPadroes.IDTPSIGNATARIO;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRPARCNEGOCIO').value = this.currentRowViewSignatariosPadroes.NRPARCNEGOCIO;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-IDTIPOASSINATURA').value = this.currentRowViewSignatariosPadroes.IDTIPOASSINATURA;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-IDTESTEMUNHA').value = this.currentRowViewSignatariosPadroes.IDTESTEMUNHA;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-NRORDENACAO').value = this.currentRowViewSignatariosPadroes.NRORDENACAO;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-DSEMAILNOTSIGNENV').value = this.currentRowViewSignatariosPadroes.DSEMAILNOTSIGNENV;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-CDOPERADOR').value = this.currentRowViewSignatariosPadroes.CDOPERADOR;
        Metadata.getInstance<Select>('formDadosContractModelViewSignatariosPadroes-DSEMAILNOTIFOUTROS').value = this.currentRowViewSignatariosPadroes.DSEMAILNOTIFOUTROS;
    }
}
